"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.destroy = exports.dispose = exports.create = exports.default = void 0;

var _rdsdataservice = _interopRequireDefault(require("aws-sdk/clients/rdsdataservice"));

var _resolveReadmodelBase = _interopRequireDefault(require("resolve-readmodel-base"));

var _crypto = _interopRequireDefault(require("crypto"));

var _connect2 = _interopRequireDefault(require("./connect"));

var _disconnect = _interopRequireDefault(require("./disconnect"));

var _count = _interopRequireDefault(require("./count"));

var _defineTable = _interopRequireDefault(require("./define-table"));

var _delete = _interopRequireDefault(require("./delete"));

var _findOne = _interopRequireDefault(require("./find-one"));

var _find = _interopRequireDefault(require("./find"));

var _insert = _interopRequireDefault(require("./insert"));

var _update = _interopRequireDefault(require("./update"));

var _beginTransaction = _interopRequireDefault(require("./begin-transaction"));

var _buildUpsertDocument = _interopRequireDefault(require("./build-upsert-document"));

var _commitTransaction = _interopRequireDefault(require("./commit-transaction"));

var _coercer = _interopRequireDefault(require("./coercer"));

var _convertResultRow = _interopRequireDefault(require("./convert-result-row"));

var _escapeId = _interopRequireDefault(require("./escape-id"));

var _escape = _interopRequireDefault(require("./escape"));

var _executeStatement = _interopRequireDefault(require("./execute-statement"));

var _rollbackTransaction = _interopRequireDefault(require("./rollback-transaction"));

var _searchToWhereExpression = _interopRequireDefault(require("./search-to-where-expression"));

var _updateToSetExpression = _interopRequireDefault(require("./update-to-set-expression"));

var _passthroughError = _interopRequireDefault(require("./passthrough-error"));

var _inlineLedgerExecuteStatement = _interopRequireDefault(require("./inline-ledger-execute-statement"));

var _inlineLedgerForceStop = _interopRequireDefault(require("./inline-ledger-force-stop"));

var _generateGuid = _interopRequireDefault(require("./generate-guid"));

var _isHighloadError = _interopRequireDefault(require("./is-highload-error"));

var _isTimeoutError = _interopRequireDefault(require("./is-timeout-error"));

var _subscribe = _interopRequireDefault(require("./subscribe"));

var _resubscribe = _interopRequireDefault(require("./resubscribe"));

var _unsubscribe = _interopRequireDefault(require("./unsubscribe"));

var _deleteProperty = _interopRequireDefault(require("./delete-property"));

var _getProperty = _interopRequireDefault(require("./get-property"));

var _listProperties = _interopRequireDefault(require("./list-properties"));

var _setProperty = _interopRequireDefault(require("./set-property"));

var _reset = _interopRequireDefault(require("./reset"));

var _pause = _interopRequireDefault(require("./pause"));

var _resume = _interopRequireDefault(require("./resume"));

var _status = _interopRequireDefault(require("./status"));

var _build = _interopRequireDefault(require("./build"));

var _beginXaTransaction = _interopRequireDefault(require("./begin-xa-transaction"));

var _beginEvent = _interopRequireDefault(require("./begin-event"));

var _commitXaTransaction = _interopRequireDefault(require("./commit-xa-transaction"));

var _commitEvent = _interopRequireDefault(require("./commit-event"));

var _rollbackXaTransaction = _interopRequireDefault(require("./rollback-xa-transaction"));

var _rollbackEvent = _interopRequireDefault(require("./rollback-event"));

var _dropReadModel = _interopRequireDefault(require("./drop-read-model"));

var _create = _interopRequireDefault(require("./resource/create"));

var _dispose = _interopRequireDefault(require("./resource/dispose"));

var _destroy = _interopRequireDefault(require("./resource/destroy"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const store = {
  defineTable: _defineTable.default,
  find: _find.default,
  findOne: _findOne.default,
  count: _count.default,
  insert: _insert.default,
  update: _update.default,
  delete: _delete.default
};
const internalMethods = {
  escapeId: _escapeId.default,
  escape: _escape.default,
  buildUpsertDocument: _buildUpsertDocument.default,
  convertResultRow: _convertResultRow.default,
  searchToWhereExpression: _searchToWhereExpression.default,
  updateToSetExpression: _updateToSetExpression.default,
  executeStatement: _executeStatement.default,
  coercer: _coercer.default,
  generateGuid: _generateGuid.default,
  PassthroughError: _passthroughError.default,
  inlineLedgerExecuteStatement: _inlineLedgerExecuteStatement.default,
  inlineLedgerForceStop: _inlineLedgerForceStop.default,
  isTimeoutError: _isTimeoutError.default,
  isHighloadError: _isHighloadError.default
};
const externalMethods = {
  beginTransaction: _beginTransaction.default,
  commitTransaction: _commitTransaction.default,
  rollbackTransaction: _rollbackTransaction.default,
  beginXATransaction: _beginXaTransaction.default,
  commitXATransaction: _commitXaTransaction.default,
  rollbackXATransaction: _rollbackXaTransaction.default,
  beginEvent: _beginEvent.default,
  commitEvent: _commitEvent.default,
  rollbackEvent: _rollbackEvent.default,
  dropReadModel: _dropReadModel.default,
  subscribe: _subscribe.default,
  resubscribe: _resubscribe.default,
  unsubscribe: _unsubscribe.default,
  deleteProperty: _deleteProperty.default,
  getProperty: _getProperty.default,
  listProperties: _listProperties.default,
  setProperty: _setProperty.default,
  resume: _resume.default,
  pause: _pause.default,
  reset: _reset.default,
  status: _status.default,
  build: _build.default
};

const connect = _connect2.default.bind(null, {
  RDSDataService: _rdsdataservice.default,
  crypto: _crypto.default,
  ...internalMethods,
  ...externalMethods,
  ...store
});

const createAdapter = _resolveReadmodelBase.default.bind(null, { ...store,
  ...externalMethods,
  connect,
  disconnect: _disconnect.default
});

var _default = createAdapter;
exports.default = _default;
const pool = {
  connect,
  disconnect: _disconnect.default,
  escapeId: _escapeId.default,
  escape: _escape.default
};

const createResource = _create.default.bind(null, pool);

exports.create = createResource;

const disposeResource = _dispose.default.bind(null, pool);

exports.dispose = disposeResource;

const destroyResource = _destroy.default.bind(null, pool);

exports.destroy = destroyResource;
Object.assign(pool, {
  createResource,
  disposeResource,
  destroyResource
});
//# sourceMappingURL=index.js.map