"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _resolveDebugLevels = _interopRequireDefault(require("resolve-debug-levels"));

var _resolveReadmodelBase = require("resolve-readmodel-base");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const log = (0, _resolveDebugLevels.default)('resolve:resolve-readmodel-postgresql-serverless:rollback-event');

const rollbackEvent = async (pool, readModelName, xaTransactionId) => {
  try {
    pool.xaTransactionId = null;
    const savepointId = pool.generateGuid(readModelName, xaTransactionId);
    await pool.rdsDataService.executeStatement({
      resourceArn: pool.dbClusterOrInstanceArn,
      secretArn: pool.awsSecretStoreArn,
      database: 'postgres',
      continueAfterTimeout: false,
      includeResultMetadata: false,
      transactionId: xaTransactionId,
      sql: `
        ROLLBACK TO SAVEPOINT ${savepointId};
        RELEASE SAVEPOINT ${savepointId};
      `
    });
    log.verbose('Rollback event to postgresql database succeed');
  } catch (error) {
    log.verbose('Rollback event to postgresql database failed', error);

    if (error != null && (/Transaction .*? Is Not Found/i.test(error.message) || /deadlock detected/i.test(error.message) || pool.isTimeoutError(error))) {
      throw _resolveReadmodelBase.OMIT_BATCH;
    }

    throw error;
  }
};

var _default = rollbackEvent;
exports.default = _default;
//# sourceMappingURL=rollback-event.js.map